@@ -5,7 +5,7 @@
 #   You may distribute under the terms of either the GNU General Public
 #   License or the Artistic License, as specified in the Perl README file.
 
-require 5.008_008;
+require 5.008_004;
 
 =head1 NAME
 
@@ -40,7 +40,7 @@ DBD::IngresII - DBI driver for Actian Ingres and Actian Vectorwise RDBMS
 
     our @ISA = qw(DynaLoader);
 
-    our $VERSION = '0.93';
+    our $VERSION = '0.94';
 
     bootstrap DBD::IngresII $VERSION;
 
@@ -1322,6 +1322,10 @@ Automatic installation with CPAN.
 
 =over 4
 
+=item*
+
+Ingres 10S Enterprise Build 126 + Solaris 10 + gcc on x86
+
 =item *
 
 Vectorwise 2.5.1 Enterprise Build 162 + Windows + Visual C++ on x64
